@@ -3,6 +3,21 @@ import astropy.units as u
 import numpy as np
 
 
+def test_empty_angular_resolution():
+    from pyirf.benchmarks import angular_resolution
+
+    events = QTable({
+        'true_energy': [] * u.TeV,
+        'theta': [] * u.deg,
+    })
+
+    table = angular_resolution(
+        events,
+        [1, 10, 100] * u.TeV
+    )
+
+    assert np.all(np.isnan(table["angular_resolution"]))
+
 def test_angular_resolution():
     from pyirf.benchmarks import angular_resolution
 
@@ -13,13 +28,18 @@ def test_angular_resolution():
     true_resolution = np.append(np.full(1000, TRUE_RES_1), np.full(1000, TRUE_RES_2))
 
     events = QTable({
-        'true_energy': np.append(np.full(1000, 5.0), np.full(1000, 50.0)) * u.TeV,
+        'true_energy': np.concatenate([
+            [0.5], # below bin 1 to test with underflow
+            np.full(999, 5.0),
+            np.full(999, 50.0),
+            [500], # above bin 2 to test with overflow
+        ]) * u.TeV,
         'theta': np.abs(np.random.normal(0, true_resolution)) * u.deg
     })
 
     ang_res = angular_resolution(
         events,
-        [1, 10, 100] * u.TeV
+        [1, 10, 100] * u.TeV,
     )['angular_resolution'].quantity
 
     assert len(ang_res) == 2
