@@ -17,7 +17,7 @@ def psf_table(events, true_energy_bins, source_offset_bins, fov_offset_bins):
         ]
     )
 
-    hist, edges = np.histogramdd(
+    hist, _ = np.histogramdd(
         array,
         [
             true_energy_bins.to_value(u.TeV),
@@ -37,15 +37,9 @@ def _normalize_psf(hist, source_offset_bins):
     # ignore numpy zero division warning
     with np.errstate(invalid="ignore"):
 
-        # to correctly divide by using broadcasting here,
-        # we need to swap the axis order
-        n_events = hist.sum(axis=2).T
-        hist = np.swapaxes(hist, 0, 2)
-
+        # normalize over the theta axis
+        n_events = hist.sum(axis=2)
         # normalize and replace nans with 0
-        psf = np.nan_to_num(hist / n_events)
-
-        # swap axes back to order required by GADF
-        psf = np.swapaxes(psf, 0, 2)
+        psf = np.nan_to_num(hist / n_events[:, :, np.newaxis])
 
     return psf / solid_angle
