@@ -2,12 +2,14 @@ import numpy as np
 
 from .utils import is_scalar
 
+__all__  = ['li_ma_significance']
+
 
 def li_ma_significance(n_on, n_off, alpha=0.2):
     """
     Calculate the Li & Ma significance.
 
-    Formula (17) doi.org/10.1086/161295
+    Formula (17) in https://doi.org/10.1086/161295
 
     This functions returns 0 significance when n_on < alpha * n_off
     instead of the negative sensitivities that would result from naively
@@ -40,11 +42,15 @@ def li_ma_significance(n_on, n_off, alpha=0.2):
         t1 = n_on * np.log(((1 + alpha) / alpha) * p_on)
         t2 = n_off * np.log((1 + alpha) * p_off)
 
+        # lim x+->0  (x log(x)) = 0
+        t1[n_on == 0] = 0
+        t2[n_off == 0] = 0
+
         ts = t1 + t2
+
         significance = np.sqrt(ts * 2)
 
-    significance[np.isnan(significance)] = 0
-    significance[n_on < alpha * n_off] = 0
+    significance[n_on < (alpha * n_off)] = 0
 
     if scalar:
         return significance[0]
